@@ -310,7 +310,10 @@ def get_investing_id(suburl, app=False):
             "Host": "cn.investing.com",
             "X-Requested-With": "XMLHttpRequest",
         }
-    r = rget(url, headers=headers,)
+    r = rget(
+        url,
+        headers=headers,
+    )
     s = BeautifulSoup(r.text, "lxml")
     pid = s.find("span", id="last_last")["class"][-1].split("-")[1]
     return pid
@@ -433,7 +436,10 @@ def get_rmb(start=None, end=None, prev=360, currency="USD/CNY"):
 def get_fund(code):
     # 随意设置非空 path，防止嵌套缓存到 fundinfo
     if code[0] == "F":
-        df = fundinfo(code[1:], path="nobackend", priceonly=True).price
+        if code.startswith("F96"):
+            return get_historical_from_ttjj_oversea(code)
+        else:
+            df = fundinfo(code[1:], path="nobackend", priceonly=True).price
     elif code[0] == "T":
         df = fundinfo(code[1:], path="nobackend", priceonly=True).price
         df["netvalue"] = df["totvalue"]
@@ -445,6 +451,31 @@ def get_fund(code):
     return df[["date", "close"]]
 
 
+def get_historical_from_ttjj_oversea(code, start=None, end=None):
+    if code.startswith("F"):
+        code = code[1:]
+    pagesize = (
+        dt.datetime.strptime(end, "%Y%m%d") - dt.datetime.strptime(start, "%Y%m%d")
+    ).days + 1
+    r = rget_json(
+        "http://overseas.1234567.com.cn/overseasapi/OpenApiHander.ashx?api=HKFDApi&m=MethodJZ&hkfcode={hkfcode}&action=2&pageindex=0&pagesize={pagesize}&date1={startdash}&date2={enddash}&callback=".format(
+            hkfcode=get_hkfcode(code),
+            pagesize=pagesize,
+            startdash=start[:4] + "-" + start[4:6] + "-" + start[6:],
+            enddash=end[:4] + "-" + end[4:6] + "-" + end[6:],
+        )
+    )
+    datalist = {"date": [], "close": []}
+    for dd in r["Data"]:
+        datalist["date"].append(pd.to_datetime(dd["PDATE"]))
+        datalist["close"].append(dd["NAV"])
+    df = pd.DataFrame(datalist)
+    df = df[df["date"] <= end]
+    df = df[df["date"] >= start]
+    df = df.sort_values("date", ascending=True)
+    return df
+
+
 def get_portfolio_fromttjj(code, start=None, end=None):
     startobj = dt.datetime.strptime(start, "%Y%m%d")
     endobj = dt.datetime.strptime(end, "%Y%m%d")
@@ -524,7 +555,7 @@ selectedModule=PerformanceGraphView&selectedSubModule=Graph\
             "upgrade-insecure-requests": "1",
         },
     )
-    df = pd.read_excel(r.content)
+    df = pd.read_excel(r.content, engine="xlrd")
     # print(df.iloc[:10])
     df = df.iloc[6:]
     df = df.dropna()
@@ -1059,7 +1090,10 @@ def _get_daily(
     elif _from in ["zhongjianjia", "zjj", "chinamoney", "ZJJ"]:
         df = get_rmb(start, end, prev, currency=code)
     elif _from in ["ttjj", "tiantianjijin", "xalpha", "eastmoney"]:
-        df = get_fund(code)
+        if code.startswith("F96"):
+            df = get_historical_from_ttjj_oversea(code, start=start, end=end)
+        else:
+            df = get_fund(code)
 
     elif _from == "peb":
         if (
@@ -1252,7 +1286,10 @@ def get_cninvesting_rt(suburl, app=False):
             "X-Requested-With": "XMLHttpRequest",
         }
 
-    r = rget(url, headers=headers,)
+    r = rget(
+        url,
+        headers=headers,
+    )
     s = BeautifulSoup(r.text, "lxml")
     last_last = s.find("span", id="last_last")
     q = _float(last_last.string)
@@ -1370,12 +1407,16 @@ def make_ft_url(code, _type="indices"):
             code=code
         )
     elif _type == "commodities":
-        url = "https://markets.ft.com/data/commodities/tearsheet/summary?c={code}".format(
-            code=code
+        url = (
+            "https://markets.ft.com/data/commodities/tearsheet/summary?c={code}".format(
+                code=code
+            )
         )
     elif _type == "currencies":
-        url = "https://markets.ft.com/data/currencies/tearsheet/summary?s={code}".format(
-            code=code
+        url = (
+            "https://markets.ft.com/data/currencies/tearsheet/summary?s={code}".format(
+                code=code
+            )
         )
     elif _type == "funds":
         url = "https://markets.ft.com/data/funds/tearsheet/summary?s={code}".format(
@@ -1469,9 +1510,64 @@ def get_newest_netvalue(code):
     )
 
 
+@lru_cache(maxsize=512)
+def get_hkfcode(code):
+    if code.startswith("F"):
+        code = code[1:]
+    page = rget("http://overseas.1234567.com.cn/{code}".format(code=code)).text
+    page.find("hkfcode")
+    hkfcode = (
+        page[page.find("hkfcode") :]
+        .split("=")[1]
+        .split(";")[0]
+        .lstrip()
+        .lstrip("'")
+        .strip("'")
+    )
+    return hkfcode
+
+
+def get_rt_from_ttjj_oversea(code):
+    if code.startswith("F"):
+        code = code[1:]
+    if not code.startswith("96"):
+        raise ValueError("%s is not an oversea fund" % code)
+    r = rget("http://overseas.1234567.com.cn/{code}.html".format(code=code))
+    r.encoding = "utf-8"
+    s = BeautifulSoup(r.text, "lxml")
+    start = s.select("dl.dataItem02")[0].text
+    start = start.split("(")[1].split(")")[0]
+    name = s.select("div[class='fundDetail-tit']")[0].text.split("（")[0].strip()
+    name = name.split("(")[0].strip()
+    value = _float(s.select("span.ui-font-large.ui-num")[0].text)
+    date = (
+        s.select("dl[class='dataItem01']")[0]
+        .find("p")
+        .text.split("(")[-1]
+        .split(")")[0]
+    )
+    infol = [
+        r for r in s.select("div[class='infoOfFund']")[0].text.split("\n") if r.strip()
+    ]
+    return {
+        "name": name,
+        "time": date,
+        "current": value,
+        "market": "CN",
+        "currency": None,  # 很可能存在非人民币计价的互认基金
+        "current_ext": None,
+        "type": infol[0].split("：")[1].strip(),
+        "scale": infol[1].split("：")[1].strip(),
+        "manager": infol[2].split("：")[1].strip(),
+        "startdate": start,
+    }
+
+
 @lru_cache_time(ttl=600, maxsize=512)
 def get_rt_from_ttjj(code):
     code = code[1:]
+    if code.startswith("96"):
+        return get_rt_from_ttjj_oversea(code)
     r = rget("http://fund.eastmoney.com/{code}.html".format(code=code))
     r.encoding = "utf-8"
     s = BeautifulSoup(r.text, "lxml")
